``tornado.platform.twisted`` --- Bridges between Twisted and Tornado
========================================================================

.. automodule:: tornado.platform.twisted

   Twisted on Tornado
   ------------------

   .. autoclass:: TornadoReactor
      :members:

   .. autofunction:: install

   Tornado on Twisted
   ------------------

   .. autoclass:: TwistedIOLoop
      :members:

   Twisted DNS resolver
   --------------------

   .. autoclass:: TwistedResolver
      :members:
